<?php

/**
 * Main Ajax Controller
 *
 * @link 		https://lin3s.com
 * @since 		1.0.0
 *
 * @package 	Alexandria_Conversation_Builder
 * @subpackage 	Alexandria_Conversation_Builder/admin/controllers
 */

if( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


/**
 * Start Builder
 *
 * @since 		1.0.0
 *
 */
function alexandria_conversation_builder_ajax() {

	$action = empty($_POST['alexandria_conversation_builder_action']) ? 'start' : $_POST['alexandria_conversation_builder_action'];

	$lang = empty($_POST['lang']) ? 'es' : $_POST['lang'];
	
	switch($action) {
		// start conversation builder
		case 'start':
		default:
		echo MainController :: intiBuilder($lang);
		break;
	}

	exit;
}

/**
 * Get interlocutors situations
 *
 * @since 		1.0.0
 *
 */
function alexandria_get_interlocutor_situations_ajax() {

	global $sitepress;

	// lang from your javascript
	$lang = empty($_POST['lang']) ? 'es' : $_POST['lang'];

	// switch to the desired language
	$sitepress->switch_lang($lang);

	$interlocutor_id = empty($_POST['interlocutor_id']) ? '' : $_POST['interlocutor_id'];

	$data = [
		'situations_categories' => []
	];

	if(empty($_POST['interlocutor_id'])) {
		echo json_encode($data);
		exit;
	}

	$args = array(  
		'post_type' => 'conversations',
		'post_status' => 'publish',
		'numberposts' => -1,
		'suppress_filters' => 0,
		'meta_query' => array(
			array(
				'key'   => '_interlocutor',
				'value' => intval($interlocutor_id),
				'meta_compare'	=> '='
			)
		)
	);

	$conversations = get_posts($args);

	foreach ($conversations as $key => $conversation) {

		$situation_id = get_post_meta( $conversation->ID, '_situation', true );
		$term = [];

		$situation = get_post($situation_id);
		$terms = get_the_terms($situation_id, 'situations-categories');
		$term = array_pop($terms);

		$data['situations_categories'][$key] = $situation;
		$data['situations_categories'][$key]->category = $term;

	}
	
	echo json_encode($data);
	exit;
}

/**
 * Get interlocutors tonos
 *
 * @since 		1.0.0
 *
 */
function alexandria_get_interlocutor_tonos_ajax() {

	global $sitepress;

	// lang from your javascript
	$lang = empty($_POST['lang']) ? 'es' : $_POST['lang'];

	// switch to the desired language
	$sitepress->switch_lang($lang);

	$interlocutor_id = empty($_POST['interlocutor_id']) ? '' : $_POST['interlocutor_id'];
	$situation_id = empty($_POST['situation_id']) ? '' : $_POST['situation_id'];

	$data = [
		'tonos' => []
	];

	if(empty($_POST['interlocutor_id']) || empty($_POST['situation_id'])) {
		echo json_encode($data);
		exit;
	}

	$args = array(  
		'post_type' => 'conversations',
		'post_status' => 'publish',
		'numberposts' => -1,
		'suppress_filters' => 0,
		'distinct' => false,
		'meta_query' => array(
			'relation' => 'AND',
			array(
				'key'   => '_interlocutor',
				'value' => intval($interlocutor_id),
				'meta_compare'	=> '='
			),
			array(
				'key'   => '_situation',
				'value' => intval($situation_id),
				'meta_compare'	=> '='
			)
		)
	);

	$conversations = get_posts($args);

	foreach ($conversations as $key => $conversation) {

		$tono_id = get_post_meta( $conversation->ID, '_tono', true );
		$tono = get_post($tono_id);

		$data['tonos'][$key] = $tono;
		$data['tonos'][$key]->background_color = get_post_meta( $tono_id, 'background_color', true );
		$data['tonos'][$key]->text_color = get_post_meta( $tono_id, 'text_color', true );
		$data['tonos'][$key]->border_color = get_post_meta( $tono_id, 'border_color', true );
	}
	
	echo json_encode($data);
	exit;
}

/**
 * Get Conversation Metadata
 *
 * @since 		1.0.0
 *
 */
function alexandria_get_custom_post_metadata_ajax() {

	$action = empty($_POST['alexandria_get_cutom_post_metadata_ajax']) ? 'metadata' : $_POST['alexandria_get_cutom_post_metadata_ajax'];

	$lang = empty($_POST['lang']) ? 'es' : $_POST['lang'];
	
	switch($action) {
		case 'metadata':
		default:
		echo MainController :: getConversationMetadata($lang);
		break;
	}

	exit;
}

/**
 * Process custom contact form send
 *
 * @since 		1.0.0
 *
 */
function alexandria_process_contact_form() {

	$text = preg_replace_callback('#{{(.*?)}}#',function($match) use ($variables){
		$match[1] = trim($match[1], '$');
		return $variables[$match[1]];
	},' ' . $template . ' ');

	$to = $_POST['email']; //sendto@example.com
	$subject = 'The subject';
	$body = 'The email body content';
	$headers = array('Content-Type: text/html; charset=UTF-8');

	wp_mail( $to, $subject, $body, $headers );

	exit;
	
}

/**
 * Order Tonos items
 *
 * @since 		1.0.0
 *
 */
function alexandria_orden_tonos_ajax() {

	parse_str($_POST['order'], $data);

	if (!is_array($data))
		return false;

	$id_arr = array();
	foreach ($data as $key => $values) {
		foreach ($values as $position => $id) {
			$id_arr[] = $id;
		}
	}

	$menu_order_arr = array();

	foreach ($id_arr as $key => $id) {

		$order = get_post_meta( $id, 'order', true );
		$menu_order_arr[] = $order;
		
	}

	sort($menu_order_arr);

	foreach ($data as $key => $values) {

		foreach ($values as $position => $id) {

			update_post_meta(intval($id), 'order', intval($menu_order_arr[$position]));

		}
	}

	exit;
	
}

/**
 * Order Interlocutors items
 *
 * @since 		1.0.0
 *
 */
function alexandria_orden_interlocutors_ajax() {

	parse_str($_POST['order'], $data);

	if (!is_array($data))
		return false;

	$id_arr = array();
	foreach ($data as $key => $values) {
		foreach ($values as $position => $id) {
			$id_arr[] = $id;
		}
	}

	$menu_order_arr = array();

	foreach ($id_arr as $key => $id) {

		$order = get_post_meta( $id, 'order', true );
		$menu_order_arr[] = $order;
		
	}

	sort($menu_order_arr);

	foreach ($data as $key => $values) {

		foreach ($values as $position => $id) {

			update_post_meta(intval($id), 'order', intval($menu_order_arr[$position]));

		}
	}

	exit;
	
}

