<?php 

/**
 * Preguntas Potentes CPT Metaboxes
 *
 *
 * @link       https://lin3s.com
 * @since      1.0.0
 *
 * @package    Alexandria_Conversation_Builder
 * @subpackage Alexandria_Conversation_Builder/admin/models
 */

/*
* Creating a function to create our CPT
*/

class Alexandria_Conversation_Preguntas_Potentes_Metaboxes {

	/**
	 * The ID of this plugin.
	 *
	 * @since 		1.0.0
	 * @access 		private
	 * @var 		string 			$plugin_name 		The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since 		1.0.0
	 * @access 		private
	 * @var 		string 			$version 			The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since 		1.0.0
	 * @param 		string 			$plugin_name 			The name of this plugin.
	 * @param 		string 			$version 				The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	function alexandria_preguntas_potentes_colors_meta_box( $post ){

		global $post, $wp_embed;

		$custom = get_post_custom( $post->ID );
		$video_id = (isset($custom["video_id"][0])) ? $custom["video_id"][0] : '';
		$video_url = (isset($custom["video_url"][0])) ? $custom["video_url"][0] : '';
		$video_type = (isset($custom["video_type"][0])) ? $custom["video_type"][0] : '';

		wp_nonce_field( 'alexandria_preguntas_potentes_video_meta_box', 'alexandria_preguntas_potentes_video_meta_box_nonce' );

		?>

		<table class="form-table">
			<tr>
				<th>
					<label for="video_type">
						<?php _e('Tipo de video de la pregunta', 'alexandria-conversation-builder')?>
					</label>
					<input id="video_url" type="hidden" data-video="media" name="video_url" value="">
					<input id="video_id" type="hidden" data-video="media" name="video_id" value="">
				</th>
				<td>
					<select name="video_type" id="video_type">
						<option value="0"><?php _e('Sin video', 'alexandria-conversation-builder')?></option>
						<option value="library" <?php echo $video_type == 'library' ? 'selected' : '' ?>><?php _e('Biblioteca de Medios (Video alojado en el propio servidor)', 'alexandria-conversation-builder')?></option>
						<option value="youtube" <?php echo  $video_type == 'youtube' ? 'selected' : '' ?>><?php _e('Youtube', 'alexandria-conversation-builder')?></option>
						<option value="vimeo" <?php echo $video_type == 'vimeo' ? 'selected' : '' ?>><?php _e('Vimeo', 'alexandria-conversation-builder')?></option>
					</select>
					<p class="description">
						<?php _e('Si quiere realizar una pregunta con video, seleccione el tipo de video que desea utilizar, . (No seleccionar ningun tipo si no se quiere pregunta en el video).', 'alexandria-conversation-builder')?>
					</p>
				</td>
			</tr>

			<tr id="library-youtube-video" style="display:<?php echo $video_type == 'youtube' ? '' : 'none' ?>">
				<th>
					<label for="video_url_youtube">
						<?php _e('URL video Youtube', 'alexandria-conversation-builder')?>
					</label>
				</th>

				<td>
					<input type="text" name="video_url_youtube" data-video="youtube" size="40" value="<?php echo $video_url ?>" />
					<p class="description">
						<?php _e('Cambiar la url y actualizar la pregunta para refrescar el video.', 'alexandria-conversation-builder'); ?>
					</p>
					<?php echo wp_oembed_get( $video_url ); ?>
					<p class="description">
						<?php _e('URL del video de Youtube. https://www.youtube.com/watch?v=xxxxxxxxxxx', 'alexandria-conversation-builder')?>
					</p>
				</td>
			</tr>

			<tr id="library-vimeo-video" style="display:<?php echo $video_type == 'vimeo' ? '' : 'none' ?>">

				<th>
					<label for="video_url_vimeo">
						<?php _e('URL del video de Vimeo.', 'alexandria-conversation-builder')?>
					</label>
				</th>

				<td>
					<input type="text" name="video_url_vimeo" data-video="vimeo" size="40" value="<?php echo $video_url?>" />
					<p class="description">
						<?php _e('Cambiar la url y actualizar la pregunta para refrescar el video.', 'alexandria-conversation-builder'); ?>
					</p>
					<?php echo wp_oembed_get( $video_url ); ?>
					<p class="description">
						<?php _e('Introduzca la url del video de vimeo.', 'alexandria-conversation-builder')?>
					</p>
				</td>

			</tr>

			<tr id="video_media_upload_row" style="display:<?php echo $video_type == 'library' ? '' : 'none' ?>">
				<th scope="row">
					<label>
						<?php _e('Video de la Biblioteca de Medios', 'alexandria-conversation-builder')?>
					</label>
				</th>

				<td>
					<div id="alexandria-video-uploader">
						<input id="media_video_title_text" type="hidden" value="<?php _e('Seleccione o suba el video de su elección', 'alexandria-conversation-builder') ?>">
						<input id="media_video_text_button" type="hidden" value="<?php _e('Usar este video', 'alexandria-conversation-builder') ?>">

						<?php if( $video = wp_get_attachment_image_src( $video_id ) ) { ?>

							<a href="#" class="upload-custom-video hidden button-primary">
								<?php echo _e('Subir video', 'alexandria-conversation-builder'); ?>
							</a>

							<a href="#" class="delete-custom-video button-primary">
								<?php echo _e('Eliminar video', 'alexandria-conversation-builder'); ?>
							</a>

							<input id="video_url" type="hidden" data-video="media" name="video_url" value="' . $video_url . '">
							<input id="video_id" type="hidden" data-video="media" name="video_id" value="' . $video_id . '">

						<?php } else { ?>

							<a href="#" class="upload-custom-video button-primary">
								<?php echo _e('Subir video', 'alexandria-conversation-builder'); ?>
							</a>

							<a href="#" class="delete-custom-video hidden button-primary">
								<?php echo _e('Eliminar video', 'alexandria-conversation-builder'); ?>
							</a>

						<?php } ?>
					</td>
				</tr>

				<tr id="video_media_preview_row" style="display:none">
					<th scope="row">
					</th>

					<td id="alexandria-video-uploader-preview">

						<?php if($video = wp_get_attachment_image_src($video_id)) { ?>

							<a href="#" class="upload-custom-img">

								<div id='video-preview' class='alexandria-video-preview-wrapper'>

									<div class="badge">
										<a class="badge-link" href="#" class="delete-custom-badge-video">X</a>
									</div>

									<img src='<?php echo $video[0] ?>' />

								</div>

							</a>

						<?php } else { ?>

							<div id='video-preview' class='alexandria-video-preview-wrapper hidden'>
								<span id="video_url_text"></span>
							</div>

							<div id='video-preview-no-video' class='alexandria-video-preview-wrapper no-video'>
								<span class="preview-text">
									<?php _e('Ningún video seleccionado')?>
								</span>
							</div>

						<?php } ?>

						<p class="description">
							<?php _e('Video de la Pregunta Potente.', 'alexandria-conversation-builder') ?>
						</p>
					</td>
				</tr>
			</table>

			<?php
		}

		function alexandria_preguntas_potentes_save_meta_boxes( $post_id ){

			if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
				return;
			}

			if( !current_user_can( 'edit_pages' ) ) {
				return;
			}

			if ( !isset( $_POST['video_type'] ) || !wp_verify_nonce( $_POST['alexandria_preguntas_potentes_video_meta_box_nonce'], 'alexandria_preguntas_potentes_video_meta_box' ) ) {
				return;
			}

			
			$video_type = (isset($_POST["video_type"]) && $_POST["video_type"]!='') ? $_POST["video_type"] : '';

			update_post_meta($post_id, "video_type", $video_type);

			if($video_type == 'youtube') {

				$video_youtube_url = (isset($_POST["video_url_youtube"]) && $_POST["video_url_youtube"]!='') ? $_POST["video_url_youtube"] : '';

				update_post_meta($post_id, "video_url", $video_youtube_url);
				
			}


			if($video_type == 'vimeo') {

				$video_vimeo_url = (isset($_POST["video_url_vimeo"]) && $_POST["video_url_vimeo"]!='') ? $_POST["video_url_vimeo"] : '';

				update_post_meta($post_id, "video_url", $video_vimeo_url);

			}


			if($video_type == 'library') {

				$video_url = (isset($_POST["video_url"]) && $_POST["video_url"]!='') ? $_POST["video_url"] : '';
				$video_id = (isset($_POST["video_id"]) && $_POST["video_id"]!='') ? $_POST["video_id"] : '';

				update_post_meta($post_id, "video_url", $video_url);
				update_post_meta($post_id, "video_id", $video_id);
			}

		}



		// Add the custom columns to the book post type:
		function set_custom_edit_preguntas_potentes_columns($columns) {
			unset( $columns['date'] );
			$columns['video_url'] = __( 'Video' );
			$columns['date'] = __( 'Date' );
			return $columns;
		}

		// Add the data to the custom columns for the book post type:
		function custom_preguntas_potentes_column( $column, $post_id ) {

			switch ( $column ) {

				case 'background_color' :
				$color = get_post_meta( $post_id, 'background_color', true );
				echo '<span style="background-color: '.$color.'; width:22px;height:22px;display:block;"></span>';
				break;
				case 'order' :
				echo $order = get_post_meta( $post_id, 'order', true );
				break;
				case 'date' :
				echo $date = get_post_meta( $post_id, 'date', true );
				break;

			}
		}

	}