<?php

/**
* The public-facing functionality of the plugin.
*
* @link 		https://lin3s.com
* @since 		1.0.0
*
* @package 	Alexandria_Conversation_builder
* @subpackage 	Alexandria_Conversation_builder/public
*/

class Alexandria_Conversation_Builder_Public {

	/**
	 * The plugin options.
	 *
	 * @since 		1.0.0
	 * @access 		private
	 * @var 		string 			$options    The plugin options.
	 */
	private $options;

	/**
	 * The ID of this plugin.
	 *
	 * @since 		1.0.0
	 * @access 		private
	 * @var 		string 			$plugin_name 		The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since 		1.0.0
	 * @access 		private
	 * @var 		string 			$version 			The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since 		1.0.0
	 * @param 		string 			$Alexandria_Conversation_Builder 	The name of the plugin.
	 * @param 		string 			$version 			The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

		define( 'ALEXANDRIA_CONVERSATION_BUILDER_PUBLIC_URL', plugin_dir_url( __FILE__ ));

		$this->set_options();
	}

	/**
	 * Add custom class to body if the template is main template
	 *
	 * @since 		1.0.0
	 */
	public function add_template_body_custom_class( $classes ) {

		$classes[] = '';
		$page_id = alexandria_conversation_builder_get_id_shortcode();

		if($page_id) {

			if(is_page( $page_id )) {
				$classes[] = 'alexandria-conversation-template';
			}
		}

		return $classes;
	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since 		1.0.0
	 */
	public function enqueue_styles() {

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/'.$this->plugin_name.'-public.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since 		1.0.0
	 */
	public function enqueue_scripts() {

		wp_register_script( $this->plugin_name.'-builder', plugin_dir_url( __FILE__ ) . 'js/'.$this->plugin_name.'-builder.js', array( 'jquery' ), $this->version, true  );
		wp_register_script( $this->plugin_name.'-form-steps', plugin_dir_url( __FILE__ ) . 'js/'.$this->plugin_name.'-form-steps.js', array( 'jquery' ), $this->version, true  );
		wp_register_script( $this->plugin_name.'-init', plugin_dir_url( __FILE__ ) . 'js/'.$this->plugin_name.'-init.js', array( 'jquery' ), $this->version, true  );
		wp_register_script( $this->plugin_name.'-copy', plugin_dir_url( __FILE__ ) . 'js/'.$this->plugin_name.'-copy.js', array( 'jquery' ), $this->version, true  );
		wp_register_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/'.$this->plugin_name.'-public.js', array( 'jquery' ), $this->version, true  );


		$translated_alexandria_conversation_builder_strings = array(
			'admin_url' => admin_url('admin-ajax.php'),
			'images_path' => ALEXANDRIA_CONVERSATION_BUILDER_PUBLIC_URL,

			'no_situacion_text' => __( 'No se han encontrado situaciones para este interlocutor.', 'alexandria-mail-builder' ),
			'no_tonos_text' => __( 'No se han encontrado tonos para este interlocutor con esta situación.', 'alexandria-mail-builder' ),

			'no_objective_text' => __( 'La conversación no tiene Objetivo', 'alexandria-conversation-builder' ),
			'no_objective_description_text'   => __( 'El objetivo no tiene descripción', 'alexandria-conversation-builder' ),

			'no_soliloquios_text' => __( 'La conversación no tiene Soliloquios', 'alexandria-conversation-builder' ),
			'no_conclusions_text' => __( 'La conversación no tiene Conclusión', 'alexandria-conversation-builder' ),
			'no_decisions_text' => __( 'La conversación no tiene Decisión', 'alexandria-conversation-builder' ),
			'no_expect_results_text' => __( 'La conversación no tiene Resultado Esperado', 'alexandria-conversation-builder' ),

			'no_relevance_text' => __( 'La conversación no tiene Relevancia', 'alexandria-conversation-builder' ),
			'no_arguments_text' => __( 'La conversación no tiene Argumentos', 'alexandria-conversation-builder' ),
			'no_viable_minimal_text' => __( 'La conversación no tiene Mínimo Viable', 'alexandria-conversation-builder' ),
			'no_comments_text' => __( 'La conversación no tiene Comentarios', 'alexandria-conversation-builder' ),
			'no_strong_questions_text' => __( 'La conversación no tiene Preguntas Potentes', 'alexandria-conversation-builder' ),
			'video_not_support_text' => __( 'Su navegador no soporta la etiqueta de vídeo.', 'alexandria-conversation-builder' ),

			'example_title' => __( 'Ejemplos', 'alexandria-conversation-builder' ),
			'no_example_text' => __( 'La conversación no tiene Ejemplos', 'alexandria-conversation-builder' ),
			'no_example_description_text'   => __( 'El Ejemplo no tiene descripción', 'alexandria-conversation-builder' ),		
		);

		wp_enqueue_script( $this->plugin_name.'-copy' );
		wp_enqueue_script( $this->plugin_name.'-builder' );
		wp_enqueue_script( $this->plugin_name.'-form-steps' );
		wp_enqueue_script( $this->plugin_name.'-init' );
		wp_enqueue_script( $this->plugin_name );

		wp_localize_script( $this->plugin_name.'-copy', 'translated_alexandria_conversation_builder_strings', $translated_alexandria_conversation_builder_strings );
		wp_localize_script( $this->plugin_name.'-builder', 'translated_alexandria_conversation_builder_strings', $translated_alexandria_conversation_builder_strings );
		wp_localize_script( $this->plugin_name.'-form-steps', 'translated_alexandria_conversation_builder_strings', $translated_alexandria_conversation_builder_strings );
		wp_localize_script( $this->plugin_name.'-init', 'translated_alexandria_conversation_builder_strings', $translated_alexandria_conversation_builder_strings );
		wp_localize_script( $this->plugin_name, 'translated_alexandria_conversation_builder_strings', $translated_alexandria_conversation_builder_strings );				
	}

	/**
	 * Processes shortcode alexandria-conversation-builder
	 *
	 * @param   array	$atts		The attributes from the shortcode
	 *
	 * @uses	get_option
	 * @uses	get_layout
	 *
	 * @return	mixed	$output		Output of the buffer
	 */
	public function add_alexandria_conversation_builder_shortcode($atts = array()) {
		ob_start();
		do_action('alexandria_conversation_builder_main_template', 'landing_page');
		return ob_get_clean();
	} // add_alexandria_mail_builder_shortcode()


	/**
	 * Registers all shortcodes at once
	 *
	 * @return [type] [description]
	 */
	public function register_shortcodes() {
		
		add_shortcode('alexandria-conversation-builder', array( $this, 'add_alexandria_conversation_builder_shortcode'));

	} // register_shortcodes()
	

	/**
	 * Adds a default single view template for a conversation builder opening
	 *
	 * @param 	string 		$template 		The name of the template
	 * @return 	mixed 						The single template
	 */
	public function single_cpt_template( $template ) {

		global $post;

		$return = $template;

		return $return;

	} // single_cpt_template()

	/**
	 * Adds a default single view template for a conversation builder opening
	 *
	 * @param 	string 		$template 		The name of the template
	 * @return 	mixed 						The single template
	 */
	public function simple_membership_check_protection() {

		global $post;

		$protected = SwpmProtection::get_instance();

		if ($protected->is_protected($post->ID)) { 

			$auth = SwpmAuth::get_instance();
			$permission = SwpmPermission::get_instance($auth->get('membership_level'));

			if(!SwpmMemberUtils::is_member_logged_in() || !$permission->is_permitted($post->ID)) {
		    	//User is not logged-in. So don't go forward.
				return 0;
			}

		}

		return true;

	} // single_cpt_template()

	/**
	 * Sets the class variable $options
	 */
	private function set_options() {

		$this->options = get_option( $this->plugin_name . '-options' );

	} // set_options()

} // class